@@ -25,7 +25,7 @@ from typing import List, Optional, cast
 
 import click
 
-from aea.cli.utils.click_utils import AgentDirectory
+from aea.cli.utils.click_utils import AgentDirectory, password_option
 from aea.cli.utils.context import Context
 from aea.cli.utils.loggers import logger
 from aea.helpers.multiple_executor import ExecutorExceptionPolicies
@@ -34,17 +34,24 @@ from aea.launcher import AEALauncher
 
 @click.command()
 @click.argument("agents", nargs=-1, type=AgentDirectory())
+@password_option()
 @click.option("--multithreaded", is_flag=True)
 @click.pass_context
 def launch(
-    click_context: click.Context, agents: List[str], multithreaded: bool
+    click_context: click.Context,
+    agents: List[str],
+    password: Optional[str],
+    multithreaded: bool,
 ) -> None:
     """Launch many agents at the same time."""
-    _launch_agents(click_context, agents, multithreaded)
+    _launch_agents(click_context, agents, multithreaded, password)
 
 
 def _launch_agents(
-    click_context: click.core.Context, agents: List[str], multithreaded: bool
+    click_context: click.core.Context,
+    agents: List[str],
+    multithreaded: bool,
+    password: Optional[str] = None,
 ) -> None:
     """
     Run multiple agents.
@@ -52,6 +59,7 @@ def _launch_agents(
     :param click_context: click context object.
     :param agents: agents names.
     :param multithreaded: bool flag to run as multithreads.
+    :param password: the password to encrypt/decrypt the private key.
 
     :return: None.
     """
@@ -64,6 +72,7 @@ def _launch_agents(
         mode=mode,
         fail_policy=ExecutorExceptionPolicies.log_only,
         log_level=ctx.verbosity,
+        password=password,
     )
 
     try:
