@@ -20,7 +20,6 @@
 import os
 import re
 import shutil
-import sys
 from pathlib import Path
 from typing import Any, Dict, Optional, Set, Tuple
 
@@ -64,10 +63,7 @@ from aea.configurations.constants import (
 from aea.configurations.loader import ConfigLoader
 from aea.configurations.manager import AgentConfigManager
 from aea.configurations.utils import replace_component_ids
-from aea.crypto.helpers import (
-    get_wallet_from_agent_config,
-    private_key_verify_or_create,
-)
+from aea.crypto.helpers import get_wallet_from_agent_config, private_key_verify
 from aea.crypto.ledger_apis import LedgerApis
 from aea.crypto.wallet import Wallet
 from aea.exceptions import AEAEnforceError
@@ -80,28 +76,30 @@ DISTRIBUTED_PACKAGES = [PublicId.from_str(dp) for dp in DISTRIBUTED_PACKAGES_STR
 ROOT = Path(".")
 
 
-def verify_or_create_private_keys_ctx(
-    ctx: Context, aea_project_path: Path = ROOT, exit_on_error: bool = False,
+def verify_private_keys_ctx(
+    ctx: Context, aea_project_path: Path = ROOT, password: Optional[str] = None,
 ) -> None:
     """
-    Verify or create private keys with ctx provided.
+    Verify private keys with ctx provided.
 
     :param ctx: Context
+    :param aea_project_path: the path to the aea project
+    :param exit_on_error: whether or not to exit on error
+    :param password: the password to encrypt/decrypt the private key.
     """
     try:
-        AgentConfigManager.verify_or_create_private_keys(
+        AgentConfigManager.verify_private_keys(
             aea_project_path,
-            private_key_helper=private_key_verify_or_create,
+            private_key_helper=private_key_verify,
             substitude_env_vars=False,
+            password=password,
         ).dump_config()
-        agent_config = AgentConfigManager.verify_or_create_private_keys(
-            aea_project_path, private_key_helper=private_key_verify_or_create
+        agent_config = AgentConfigManager.verify_private_keys(
+            aea_project_path, private_key_helper=private_key_verify, password=password,
         ).agent_config
         if ctx is not None:
             ctx.agent_config = agent_config
     except ValueError as e:  # pragma: nocover
-        if exit_on_error:
-            sys.exit(1)
         raise click.ClickException(str(e))
 
 
@@ -139,7 +137,7 @@ def _is_permitted_author_handle(author: str) -> bool:
     Check that the author handle is permitted.
 
     :param author: the author
-    :retun: bool
+    :return: bool
     """
     result = author not in NOT_PERMITTED_AUTHORS
     return result
@@ -200,9 +198,9 @@ def get_package_path(
     :param project_directory: path to search packages
     :param item_type: item type.
     :param public_id: item public ID.
-    :param is_vendor: flag for vendorized path (True by defaut).
+    :param is_vendor: flag for vendorized path (True by default).
 
-    :return: vendorized estenation path for package.
+    :return: vendorized destination path for package.
     """
     item_type_plural = item_type + "s"
     if is_vendor:
@@ -234,7 +232,7 @@ def get_package_path_unified(
     :param item_type: item type.
     :param public_id: item public ID.
 
-    :return: vendorized estenation path for package.
+    :return: vendorized destination path for package.
     """
     vendor_path = get_package_path(
         project_directory, item_type, public_id, is_vendor=True
@@ -269,7 +267,7 @@ def copy_package_directory(src: Path, dst: str) -> Path:
      Copy a package directory to the agent vendor resources.
 
     :param src: source path to the package to be added.
-    :param dst: str package destenation path.
+    :param dst: str package destination path.
 
     :return: copied folder target path.
     :raises SystemExit: if the copy raises an exception.
@@ -305,13 +303,8 @@ def find_item_locally(
     item_name = item_public_id.name
 
     # check in registry
-    registry_path = (
-        os.path.join(ctx.cwd, ctx.agent_config.registry_path)
-        if ctx.registry_path is None
-        else ctx.registry_path
-    )
     package_path = Path(
-        registry_path, item_public_id.author, item_type_plural, item_name
+        ctx.registry_path, item_public_id.author, item_type_plural, item_name
     )
     config_file_name = _get_default_configuration_file_name_from_type(item_type)
     item_configuration_filepath = package_path / config_file_name
@@ -362,8 +355,7 @@ def find_item_in_distribution(  # pylint: disable=unused-argument
     item_name = item_public_id.name
 
     # check in aea dir
-    registry_path = AEA_DIR
-    package_path = Path(registry_path, item_type_plural, item_name)
+    package_path = Path(AEA_DIR, item_type_plural, item_name)
     config_file_name = _get_default_configuration_file_name_from_type(item_type)
     item_configuration_filepath = package_path / config_file_name
     if not item_configuration_filepath.exists():
@@ -565,7 +557,7 @@ def get_item_public_id_by_author_name(
     agent_config: AgentConfig, item_type: str, author: str, name: str
 ) -> Optional[PublicId]:
     """
-    Get component public_id by author and namme.
+    Get component public_id by author and name.
 
     :param agent_config: AgentConfig
     :param item_type: str. component type: connection, skill, contract, protocol
@@ -632,7 +624,7 @@ def try_get_balance(  # pylint: disable=unused-argument
     :param wallet: wallet object.
     :param type_: type of ledger API.
 
-    :retun: token balance.
+    :return: token balance.
     """
     try:
         if not LedgerApis.has_ledger(type_):  # pragma: no cover
@@ -648,7 +640,7 @@ def try_get_balance(  # pylint: disable=unused-argument
         raise click.ClickException(str(e))
 
 
-def get_wallet_from_context(ctx: Context) -> Wallet:
+def get_wallet_from_context(ctx: Context, password: Optional[str] = None) -> Wallet:
     """
     Get wallet from current click Context.
 
@@ -656,8 +648,8 @@ def get_wallet_from_context(ctx: Context) -> Wallet:
 
     :return: wallet
     """
-    verify_or_create_private_keys_ctx(ctx=ctx)
-    wallet = get_wallet_from_agent_config(ctx.agent_config)
+    verify_private_keys_ctx(ctx=ctx, password=password)
+    wallet = get_wallet_from_agent_config(ctx.agent_config, password=password)
     return wallet
 
 
