@@ -131,10 +131,21 @@ def load_aea_package(configuration: ComponentConfiguration) -> None:
     prefix_author = prefix_root + f".{configuration.author}"
     prefix_pkg_type = prefix_author + f".{configuration.component_type.to_plural()}"
     prefix_pkg = prefix_pkg_type + f".{configuration.name}"
-    sys.modules[prefix_root] = types.ModuleType(prefix_root)
-    sys.modules[prefix_author] = types.ModuleType(prefix_author)
-    sys.modules[prefix_pkg_type] = types.ModuleType(prefix_pkg_type)
 
+    # update modules if no registered already
+    # path is required to mark module as a package
+    prefix_root_module = types.ModuleType(prefix_root)
+    prefix_root_module.__path__ = None  # type: ignore
+    sys.modules[prefix_root] = sys.modules.get(prefix_root, prefix_root_module)
+    author_module = types.ModuleType(prefix_author)
+    author_module.__path__ = None  # type: ignore
+    sys.modules[prefix_author] = sys.modules.get(prefix_author, author_module)
+    prefix_pkg_type_module = types.ModuleType(prefix_pkg_type)
+    prefix_pkg_type_module.__path__ = None  # type: ignore
+
+    sys.modules[prefix_pkg_type] = sys.modules.get(
+        prefix_pkg_type, prefix_pkg_type_module
+    )
     for subpackage_init_file in dir_.rglob("__init__.py"):
         parent_dir = subpackage_init_file.parent
         relative_parent_dir = parent_dir.relative_to(dir_)
@@ -142,7 +153,7 @@ def load_aea_package(configuration: ComponentConfiguration) -> None:
             # this handles the case when 'subpackage_init_file'
             # is path/to/package/__init__.py
             import_path = prefix_pkg
-        else:
+        else:  # pragma: nocover
             import_path = prefix_pkg + "." + ".".join(relative_parent_dir.parts)
 
         spec = importlib.util.spec_from_file_location(import_path, subpackage_init_file)
