@@ -19,7 +19,6 @@
 """Module wrapping the helpers of public and private key cryptography."""
 import logging
 import os
-import sys
 from pathlib import Path
 from typing import Dict, Optional
 
@@ -37,44 +36,43 @@ _ = PRIVATE_KEY_PATH_SCHEMA  # some modules expect this here
 
 
 def try_validate_private_key_path(
-    ledger_id: str, private_key_path: str, exit_on_error: bool = True
+    ledger_id: str, private_key_path: str, password: Optional[str] = None,
 ) -> None:
     """
     Try validate a private key path.
 
     :param ledger_id: one of 'fetchai', 'ethereum'
     :param private_key_path: the path to the private key.
+    :param password: the password to encrypt/decrypt the private key.
     :return: None
     :raises: ValueError if the identifier is invalid.
     """
     try:
         # to validate the file, we just try to create a crypto object
         # with private_key_path as parameter
-        make_crypto(ledger_id, private_key_path=private_key_path)
-    except Exception as e:  # pylint: disable=broad-except  # thats ok, will exit or reraise
+        make_crypto(ledger_id, private_key_path=private_key_path, password=password)
+    except Exception as e:  # pylint: disable=broad-except  # thats ok, reraise
         error_msg = "This is not a valid private key file: '{}'\n Exception: '{}'".format(
             private_key_path, e
         )
-        if exit_on_error:
-            _default_logger.exception(error_msg)  # show exception traceback on exit
-            sys.exit(1)
-        else:  # pragma: no cover
-            _default_logger.error(error_msg)
-            raise
+        _default_logger.error(error_msg)
+        raise
 
 
-def create_private_key(ledger_id: str, private_key_file: str) -> None:
+def create_private_key(
+    ledger_id: str, private_key_file: str, password: Optional[str] = None
+) -> None:
     """
     Create a private key for the specified ledger identifier.
 
     :param ledger_id: the ledger identifier.
     :param private_key_file: the private key file.
+    :param password: the password to encrypt/decrypt the private key.
     :return: None
     :raises: ValueError if the identifier is invalid.
     """
     crypto = make_crypto(ledger_id)
-    with open(private_key_file, "wb") as fp:
-        crypto.dump(fp)
+    crypto.dump(private_key_file, password)
 
 
 def try_generate_testnet_wealth(
@@ -94,14 +92,15 @@ def try_generate_testnet_wealth(
         faucet_api.get_wealth(address, url)
 
 
-def private_key_verify_or_create(
-    aea_conf: AgentConfig, aea_project_path: Path, create_keys: bool = True
+def private_key_verify(
+    aea_conf: AgentConfig, aea_project_path: Path, password: Optional[str] = None,
 ) -> None:
     """
-    Check key or create if none present.
+    Check key.
 
     :param aea_conf: AgentConfig
     :param aea_project_path: Path, where project placed.
+    :param password: the password to encrypt/decrypt the private key.
 
     :return: None
     """
@@ -117,52 +116,61 @@ def private_key_verify_or_create(
         config_private_key_path = aea_conf.private_key_paths.read(identifier)
 
         if is_env_variable(config_private_key_path):
-            # config_private_key_path is env vaariable to be used, skip it. check will be performed after substitution
+            # config_private_key_path is env variable to be used, skip it. check will be performed after substitution
             continue
 
         if config_private_key_path is None:
-            private_key_path = PRIVATE_KEY_PATH_SCHEMA.format(identifier)
-            if identifier == aea_conf.default_ledger:  # pragma: nocover
-                if os.path.exists(private_key_path):
-                    raise ValueError(
-                        "File {} for private key {} already exists. Add to aea-config.yaml.".format(
-                            repr(config_private_key_path), identifier
-                        )
-                    )
-                if create_keys:
-                    create_private_key(
-                        identifier,
-                        private_key_file=str(aea_project_path / private_key_path),
-                    )
-                    aea_conf.private_key_paths.update(identifier, private_key_path)
-        else:
-            try:
-                try_validate_private_key_path(
-                    identifier,
-                    str(aea_project_path / config_private_key_path),
-                    exit_on_error=False,  # do not exit process
-                )
-            except FileNotFoundError:  # pragma: no cover
-                raise ValueError(
-                    "File {} for private key {} not found.".format(
-                        repr(config_private_key_path), identifier,
-                    )
+            continue
+        try:
+            try_validate_private_key_path(
+                identifier,
+                str(aea_project_path / config_private_key_path),
+                password=password,
+            )
+        except FileNotFoundError:  # pragma: no cover
+            raise ValueError(
+                "File {} for private key {} not found.".format(
+                    repr(config_private_key_path), identifier,
                 )
+            )
 
 
 def make_certificate(
-    ledger_id: str, crypto_private_key_path: str, message: bytes, output_path: str
+    ledger_id: str,
+    crypto_private_key_path: str,
+    message: bytes,
+    output_path: str,
+    password: Optional[str] = None,
 ) -> str:
-    """Create certificate."""
-    crypto = crypto_registry.make(ledger_id, private_key_path=crypto_private_key_path)
+    """
+    Create certificate.
+
+    :param ledger_id: the ledger id
+    :param crypto_private_key_path: the path to the private key.
+    :param message: the message to be signed.
+    :param output_path: the location where to save the certificate.
+    :param password: the password to encrypt/decrypt the private keys.
+    :return: the signature/certificate
+    """
+    crypto = crypto_registry.make(
+        ledger_id, private_key_path=crypto_private_key_path, password=password
+    )
     signature = crypto.sign_message(message).encode("ascii").hex()
     ensure_dir(os.path.dirname(output_path))
     Path(output_path).write_bytes(signature.encode("ascii"))
     return signature
 
 
-def get_wallet_from_agent_config(agent_config: AgentConfig) -> Wallet:
-    """Get wallet from agent_cofig provided."""
+def get_wallet_from_agent_config(
+    agent_config: AgentConfig, password: Optional[str] = None
+) -> Wallet:
+    """
+    Get wallet from agent_cofig provided.
+
+    :param agent_config: the agent configuration object
+    :param password: the password to encrypt/decrypt the private keys.
+    :return: wallet
+    """
     private_key_paths: Dict[str, Optional[str]] = {
         config_pair[0]: config_pair[1]
         for config_pair in agent_config.private_key_paths.read_all()
@@ -171,5 +179,27 @@ def get_wallet_from_agent_config(agent_config: AgentConfig) -> Wallet:
         config_pair[0]: config_pair[1]
         for config_pair in agent_config.connection_private_key_paths.read_all()
     }
-    wallet = Wallet(private_key_paths, connections_private_key_paths)
+    wallet = Wallet(private_key_paths, connections_private_key_paths, password=password)
     return wallet
+
+
+class DecryptError(ValueError):
+    """Error on bytes decryption with password."""
+
+    msg = "Decrypt error! Bad password?"
+
+    def __init__(self, msg: Optional[str] = None) -> None:
+        """Init exception."""
+        super().__init__(msg or self.msg)
+
+
+class KeyIsIncorrect(ValueError):
+    """Error decoding hex string to bytes for private key."""
+
+
+def hex_to_bytes_for_key(data: str) -> bytes:
+    """Convert hex string to bytes with error handling."""
+    try:
+        return bytes.fromhex(data)
+    except ValueError as e:
+        raise KeyIsIncorrect(str(e)) from e
