@@ -20,6 +20,7 @@
 """This module contains the default error handler class."""
 
 from logging import Logger
+from typing import Any
 
 from aea.error_handler.base import AbstractErrorHandler
 from aea.mail.base import Envelope
@@ -28,26 +29,33 @@ from aea.mail.base import Envelope
 class ErrorHandler(AbstractErrorHandler):
     """Error handler class for handling problematic envelopes."""
 
-    unsupported_protocol_count = 0
-    no_active_handler_count = 0
-    decoding_error_count = 0
+    __slots__ = (
+        "unsupported_protocol_count",
+        "no_active_handler_count",
+        "decoding_error_count",
+    )
 
-    @classmethod
-    def send_unsupported_protocol(cls, envelope: Envelope, logger: Logger) -> None:
+    def __init__(self, **kwargs: Any):
+        """Instantiate error handler."""
+        super().__init__(**kwargs)
+        self.unsupported_protocol_count = 0
+        self.no_active_handler_count = 0
+        self.decoding_error_count = 0
+
+    def send_unsupported_protocol(self, envelope: Envelope, logger: Logger) -> None:
         """
         Handle the received envelope in case the protocol is not supported.
 
         :param envelope: the envelope
         :return: None
         """
-        cls.unsupported_protocol_count += 1
+        self.unsupported_protocol_count += 1
         logger.warning(
             f"Unsupported protocol: protocol_specification_id={envelope.protocol_specification_id}. You might want to add a handler for a protocol implementing this specification. Sender={envelope.sender}, to={envelope.sender}."
         )
 
-    @classmethod
     def send_decoding_error(
-        cls, envelope: Envelope, exception: Exception, logger: Logger
+        self, envelope: Envelope, exception: Exception, logger: Logger
     ) -> None:
         """
         Handle a decoding error.
@@ -57,14 +65,13 @@ class ErrorHandler(AbstractErrorHandler):
         :param logger: the logger
         :return: None
         """
-        cls.decoding_error_count += 1
+        self.decoding_error_count += 1
         logger.warning(
             f"Decoding error for envelope: {envelope}. Protocol_specification_id='{envelope.protocol_specification_id}' and message are inconsistent. Sender={envelope.sender}, to={envelope.sender}. Exception={exception}."
         )
 
-    @classmethod
     def send_no_active_handler(
-        cls, envelope: Envelope, reason: str, logger: Logger
+        self, envelope: Envelope, reason: str, logger: Logger
     ) -> None:
         """
         Handle the received envelope in case the handler is not supported.
@@ -73,7 +80,7 @@ class ErrorHandler(AbstractErrorHandler):
         :param reason: the reason for the failure
         :return: None
         """
-        cls.no_active_handler_count += 1
+        self.no_active_handler_count += 1
         logger.warning(
             f"Cannot handle envelope: {reason}. Sender={envelope.sender}, to={envelope.sender}."
         )
