@@ -67,6 +67,10 @@ class AEAComponentLoadException(AEAException):
     """Class for component loading errors of an AEA."""
 
 
+class AEAWalletNoAddressException(AEAException):
+    """Class for attempts to instantiate a wallet without addresses."""
+
+
 class _StopRuntime(Exception):
     """
     Exception to stop runtime.
