@@ -165,7 +165,7 @@ class BaseAEATestCase(ABC):  # pylint: disable=too-many-public-methods
 
         :param args: CLI args
         :param cwd: the working directory from where to run the command.
-        :param kwargs: other keyword arguments to click.CLIRunner.invoke.
+        :param kwargs: other keyword arguments to click.CliRunner.invoke.
         :raises AEATestingException: if command fails.
 
         :return: Result
@@ -325,8 +325,8 @@ class BaseAEATestCase(ABC):  # pylint: disable=too-many-public-methods
                 "version",
                 "connection_private_key_paths",
                 "private_key_paths",
-                "registry_path",
-                "dependencies",  # temporary
+                "dependencies",
+                "required_ledgers",
             ]
             result = all(
                 [key in allowed_diff_keys for key in content1_agentconfig.keys()]
@@ -694,7 +694,7 @@ class BaseAEATestCase(ABC):  # pylint: disable=too-many-public-methods
     @classmethod
     def replace_file_content(cls, src: Path, dest: Path) -> None:  # pragma: nocover
         """
-        Replace the content of the source file to the dest file.
+        Replace the content of the source file to the destination file.
 
         :param src: the source file.
         :param dest: the destination file.
@@ -951,7 +951,7 @@ class AEATestCaseEmpty(BaseAEATestCase):
     def setup_class(cls) -> None:
         """Set up the test class."""
         super(AEATestCaseEmpty, cls).setup_class()
-        cls.agent_name = "agent-" + "".join(random.choices(string.ascii_lowercase, k=5))
+        cls.agent_name = "agent_" + "".join(random.choices(string.ascii_lowercase, k=5))
         cls.create_agents(cls.agent_name, is_local=cls.IS_LOCAL, is_empty=cls.IS_EMPTY)
         cls.set_agent_context(cls.agent_name)
 
