@@ -19,26 +19,29 @@
 
 """This module contains the erc1155 contract definition."""
 
-import json
 import logging
 import random
 from typing import Dict, List, Optional, cast
 
-from vyper.utils import keccak256
+from aea_ledger_cosmos import CosmosApi
+from aea_ledger_ethereum import EthereumApi
+from aea_ledger_fetchai import FetchAIApi
 
 from aea.common import Address, JSONLike
 from aea.configurations.base import PublicId
 from aea.contracts.base import Contract
 from aea.crypto.base import LedgerApi
-from aea.crypto.cosmos import CosmosApi
-from aea.crypto.ethereum import EthereumApi
-from aea.crypto.fetchai import FetchAIApi
 
 
 _default_logger = logging.getLogger("aea.packages.fetchai.contracts.erc1155.contract")
 MAX_UINT_256 = 2 ^ 256 - 1
 
-PUBLIC_ID = PublicId.from_str("fetchai/erc1155:0.13.0")
+PUBLIC_ID = PublicId.from_str("fetchai/erc1155:0.21.0")
+
+
+def keccak256(input_: bytes) -> bytes:
+    """Compute hash."""
+    return bytes(bytearray.fromhex(EthereumApi.get_hash(input_)[2:]))
 
 
 class ERC1155Contract(Contract):
@@ -350,11 +353,14 @@ class ERC1155Contract(Contract):
             return {"balance": result}
         if ledger_api.identifier in [CosmosApi.identifier, FetchAIApi.identifier]:
             cosmos_api = cast(CosmosApi, ledger_api)
-            msg = {"balance": {"address": str(agent_address), "id": str(token_id)}}
-            query_res = cosmos_api.try_execute_wasm_query(contract_address, msg)
-            query_json_res = json.loads(query_res)
+            msg: JSONLike = {
+                "balance": {"address": str(agent_address), "id": str(token_id)}
+            }
+            query_res = cosmos_api.execute_contract_query(contract_address, msg)
+            if query_res is None:
+                raise ValueError("call to contract returned None")
             # Convert {"balance": balance: str} balances to Dict[token_id: int, balance: int]
-            result = {token_id: int(query_json_res["balance"])}
+            result = {token_id: int(cast(str, query_res["balance"]))}
             return {"balance": result}
         raise NotImplementedError
 
@@ -447,15 +453,18 @@ class ERC1155Contract(Contract):
             for token_id in token_ids:
                 tokens.append({"address": agent_address, "id": str(token_id)})
 
-            msg = {"balance_batch": {"addresses": tokens}}
+            msg: JSONLike = {"balance_batch": {"addresses": tokens}}
 
             cosmos_api = cast(CosmosApi, ledger_api)
-            query_res = cosmos_api.try_execute_wasm_query(contract_address, msg)
-            query_json_res = json.loads(query_res)
+            query_res = cosmos_api.execute_contract_query(contract_address, msg)
             # Convert List[balances: str] balances to Dict[token_id: int, balance: int]
+            if query_res is None:
+                raise ValueError("call to contract returned None")
             result = {
                 token_id: int(balance)
-                for token_id, balance in zip(token_ids, query_json_res["balances"])
+                for token_id, balance in zip(
+                    token_ids, cast(List[str], query_res["balances"])
+                )
             }
             return {"balances": result}
         raise NotImplementedError
@@ -629,7 +638,7 @@ class ERC1155Contract(Contract):
         trade_nonce: int,
     ) -> bytes:
         """
-        Get the hash for a trustless trade between two agents for a single token.
+        Get the hash for a trustless trade between two agents for a batch of tokens.
 
         :param ledger_api: the ledger API
         :param contract_address: the address of the contract
@@ -745,32 +754,3 @@ class ERC1155Contract(Contract):
                 trade_nonce = random.randrange(0, MAX_UINT_256)  # nosec
             return {"trade_nonce": trade_nonce}
         raise NotImplementedError
-
-    @staticmethod
-    def get_last_code_id(ledger_api: LedgerApi) -> int:
-        """
-        Uses wasmcli to get ID of latest deployed .wasm bytecode
-
-        :param ledger_api: the ledger API
-
-        :return: code id of last deployed .wasm bytecode
-        """
-        if ledger_api.identifier in [CosmosApi.identifier, FetchAIApi.identifier]:
-            cosmos_api = cast(CosmosApi, ledger_api)
-            return cosmos_api.get_last_code_id()
-        raise NotImplementedError
-
-    @staticmethod
-    def get_contract_address(ledger_api: LedgerApi, code_id: int) -> str:
-        """
-        Uses wasmcli to get contract address of latest initialised contract by its ID
-
-        :param ledger_api: the ledger API
-        :param code_id: the ID of stored contract CosmWasm
-
-        :return: contract address of last initialised contract
-        """
-        if ledger_api.identifier in [CosmosApi.identifier, FetchAIApi.identifier]:
-            cosmos_api = cast(CosmosApi, ledger_api)
-            return cosmos_api.get_contract_address(code_id)
-        raise NotImplementedError
