@@ -19,6 +19,7 @@
 
 """This module contains gym's message definition."""
 
+# pylint: disable=too-many-statements,too-many-locals,no-member,too-few-public-methods,too-many-branches,not-an-iterable,unidiomatic-typecheck,unsubscriptable-object
 import logging
 from typing import Any, Dict, Set, Tuple, cast
 
@@ -37,8 +38,8 @@ DEFAULT_BODY_SIZE = 4
 class GymMessage(Message):
     """A protocol for interacting with a gym connection."""
 
-    protocol_id = PublicId.from_str("fetchai/gym:0.13.0")
-    protocol_specification_id = PublicId.from_str("fetchai/gym:0.1.0")
+    protocol_id = PublicId.from_str("fetchai/gym:1.0.0")
+    protocol_specification_id = PublicId.from_str("fetchai/gym:1.0.0")
 
     AnyObject = CustomAnyObject
 
@@ -172,31 +173,31 @@ class GymMessage(Message):
         """Check that the message follows the gym protocol."""
         try:
             enforce(
-                type(self.dialogue_reference) == tuple,
+                isinstance(self.dialogue_reference, tuple),
                 "Invalid type for 'dialogue_reference'. Expected 'tuple'. Found '{}'.".format(
                     type(self.dialogue_reference)
                 ),
             )
             enforce(
-                type(self.dialogue_reference[0]) == str,
+                isinstance(self.dialogue_reference[0], str),
                 "Invalid type for 'dialogue_reference[0]'. Expected 'str'. Found '{}'.".format(
                     type(self.dialogue_reference[0])
                 ),
             )
             enforce(
-                type(self.dialogue_reference[1]) == str,
+                isinstance(self.dialogue_reference[1], str),
                 "Invalid type for 'dialogue_reference[1]'. Expected 'str'. Found '{}'.".format(
                     type(self.dialogue_reference[1])
                 ),
             )
             enforce(
-                type(self.message_id) == int,
+                type(self.message_id) is int,
                 "Invalid type for 'message_id'. Expected 'int'. Found '{}'.".format(
                     type(self.message_id)
                 ),
             )
             enforce(
-                type(self.target) == int,
+                type(self.target) is int,
                 "Invalid type for 'target'. Expected 'int'. Found '{}'.".format(
                     type(self.target)
                 ),
@@ -205,7 +206,7 @@ class GymMessage(Message):
             # Light Protocol Rule 2
             # Check correct performative
             enforce(
-                type(self.performative) == GymMessage.Performative,
+                isinstance(self.performative, GymMessage.Performative),
                 "Invalid 'performative'. Expected either of '{}'. Found '{}'.".format(
                     self.valid_performatives, self.performative
                 ),
@@ -217,13 +218,13 @@ class GymMessage(Message):
             if self.performative == GymMessage.Performative.ACT:
                 expected_nb_of_contents = 2
                 enforce(
-                    type(self.action) == CustomAnyObject,
+                    isinstance(self.action, CustomAnyObject),
                     "Invalid type for content 'action'. Expected 'AnyObject'. Found '{}'.".format(
                         type(self.action)
                     ),
                 )
                 enforce(
-                    type(self.step_id) == int,
+                    type(self.step_id) is int,
                     "Invalid type for content 'step_id'. Expected 'int'. Found '{}'.".format(
                         type(self.step_id)
                     ),
@@ -231,31 +232,31 @@ class GymMessage(Message):
             elif self.performative == GymMessage.Performative.PERCEPT:
                 expected_nb_of_contents = 5
                 enforce(
-                    type(self.step_id) == int,
+                    type(self.step_id) is int,
                     "Invalid type for content 'step_id'. Expected 'int'. Found '{}'.".format(
                         type(self.step_id)
                     ),
                 )
                 enforce(
-                    type(self.observation) == CustomAnyObject,
+                    isinstance(self.observation, CustomAnyObject),
                     "Invalid type for content 'observation'. Expected 'AnyObject'. Found '{}'.".format(
                         type(self.observation)
                     ),
                 )
                 enforce(
-                    type(self.reward) == float,
+                    isinstance(self.reward, float),
                     "Invalid type for content 'reward'. Expected 'float'. Found '{}'.".format(
                         type(self.reward)
                     ),
                 )
                 enforce(
-                    type(self.done) == bool,
+                    isinstance(self.done, bool),
                     "Invalid type for content 'done'. Expected 'bool'. Found '{}'.".format(
                         type(self.done)
                     ),
                 )
                 enforce(
-                    type(self.info) == CustomAnyObject,
+                    isinstance(self.info, CustomAnyObject),
                     "Invalid type for content 'info'. Expected 'AnyObject'. Found '{}'.".format(
                         type(self.info)
                     ),
@@ -263,20 +264,20 @@ class GymMessage(Message):
             elif self.performative == GymMessage.Performative.STATUS:
                 expected_nb_of_contents = 1
                 enforce(
-                    type(self.content) == dict,
+                    isinstance(self.content, dict),
                     "Invalid type for content 'content'. Expected 'dict'. Found '{}'.".format(
                         type(self.content)
                     ),
                 )
                 for key_of_content, value_of_content in self.content.items():
                     enforce(
-                        type(key_of_content) == str,
+                        isinstance(key_of_content, str),
                         "Invalid type for dictionary keys in content 'content'. Expected 'str'. Found '{}'.".format(
                             type(key_of_content)
                         ),
                     )
                     enforce(
-                        type(value_of_content) == str,
+                        isinstance(value_of_content, str),
                         "Invalid type for dictionary values in content 'content'. Expected 'str'. Found '{}'.".format(
                             type(value_of_content)
                         ),
