@@ -19,6 +19,7 @@
 
 """This module contains ml_trade's message definition."""
 
+# pylint: disable=too-many-statements,too-many-locals,no-member,too-few-public-methods,too-many-branches,not-an-iterable,unidiomatic-typecheck,unsubscriptable-object
 import logging
 from typing import Any, Set, Tuple, cast
 
@@ -40,8 +41,8 @@ DEFAULT_BODY_SIZE = 4
 class MlTradeMessage(Message):
     """A protocol for trading data for training and prediction purposes."""
 
-    protocol_id = PublicId.from_str("fetchai/ml_trade:0.13.0")
-    protocol_specification_id = PublicId.from_str("fetchai/ml_trade:0.1.0")
+    protocol_id = PublicId.from_str("fetchai/ml_trade:1.0.0")
+    protocol_specification_id = PublicId.from_str("fetchai/ml_trade:1.0.0")
 
     Description = CustomDescription
 
@@ -155,31 +156,31 @@ class MlTradeMessage(Message):
         """Check that the message follows the ml_trade protocol."""
         try:
             enforce(
-                type(self.dialogue_reference) == tuple,
+                isinstance(self.dialogue_reference, tuple),
                 "Invalid type for 'dialogue_reference'. Expected 'tuple'. Found '{}'.".format(
                     type(self.dialogue_reference)
                 ),
             )
             enforce(
-                type(self.dialogue_reference[0]) == str,
+                isinstance(self.dialogue_reference[0], str),
                 "Invalid type for 'dialogue_reference[0]'. Expected 'str'. Found '{}'.".format(
                     type(self.dialogue_reference[0])
                 ),
             )
             enforce(
-                type(self.dialogue_reference[1]) == str,
+                isinstance(self.dialogue_reference[1], str),
                 "Invalid type for 'dialogue_reference[1]'. Expected 'str'. Found '{}'.".format(
                     type(self.dialogue_reference[1])
                 ),
             )
             enforce(
-                type(self.message_id) == int,
+                type(self.message_id) is int,
                 "Invalid type for 'message_id'. Expected 'int'. Found '{}'.".format(
                     type(self.message_id)
                 ),
             )
             enforce(
-                type(self.target) == int,
+                type(self.target) is int,
                 "Invalid type for 'target'. Expected 'int'. Found '{}'.".format(
                     type(self.target)
                 ),
@@ -188,7 +189,7 @@ class MlTradeMessage(Message):
             # Light Protocol Rule 2
             # Check correct performative
             enforce(
-                type(self.performative) == MlTradeMessage.Performative,
+                isinstance(self.performative, MlTradeMessage.Performative),
                 "Invalid 'performative'. Expected either of '{}'. Found '{}'.".format(
                     self.valid_performatives, self.performative
                 ),
@@ -200,7 +201,7 @@ class MlTradeMessage(Message):
             if self.performative == MlTradeMessage.Performative.CFP:
                 expected_nb_of_contents = 1
                 enforce(
-                    type(self.query) == CustomQuery,
+                    isinstance(self.query, CustomQuery),
                     "Invalid type for content 'query'. Expected 'Query'. Found '{}'.".format(
                         type(self.query)
                     ),
@@ -208,7 +209,7 @@ class MlTradeMessage(Message):
             elif self.performative == MlTradeMessage.Performative.TERMS:
                 expected_nb_of_contents = 1
                 enforce(
-                    type(self.terms) == CustomDescription,
+                    isinstance(self.terms, CustomDescription),
                     "Invalid type for content 'terms'. Expected 'Description'. Found '{}'.".format(
                         type(self.terms)
                     ),
@@ -216,13 +217,13 @@ class MlTradeMessage(Message):
             elif self.performative == MlTradeMessage.Performative.ACCEPT:
                 expected_nb_of_contents = 2
                 enforce(
-                    type(self.terms) == CustomDescription,
+                    isinstance(self.terms, CustomDescription),
                     "Invalid type for content 'terms'. Expected 'Description'. Found '{}'.".format(
                         type(self.terms)
                     ),
                 )
                 enforce(
-                    type(self.tx_digest) == str,
+                    isinstance(self.tx_digest, str),
                     "Invalid type for content 'tx_digest'. Expected 'str'. Found '{}'.".format(
                         type(self.tx_digest)
                     ),
@@ -230,13 +231,13 @@ class MlTradeMessage(Message):
             elif self.performative == MlTradeMessage.Performative.DATA:
                 expected_nb_of_contents = 2
                 enforce(
-                    type(self.terms) == CustomDescription,
+                    isinstance(self.terms, CustomDescription),
                     "Invalid type for content 'terms'. Expected 'Description'. Found '{}'.".format(
                         type(self.terms)
                     ),
                 )
                 enforce(
-                    type(self.payload) == bytes,
+                    isinstance(self.payload, bytes),
                     "Invalid type for content 'payload'. Expected 'bytes'. Found '{}'.".format(
                         type(self.payload)
                     ),
