@@ -17,7 +17,11 @@
 #
 # ------------------------------------------------------------------------------
 
-"""This module contains the support resources for the state_update protocol."""
+"""
+This module contains the support resources for the state_update protocol.
+
+It was created with protocol buffer compiler version `libprotoc 3.11.4` and aea version `1.0.0`.
+"""
 
 from packages.fetchai.protocols.state_update.message import StateUpdateMessage
 from packages.fetchai.protocols.state_update.serialization import StateUpdateSerializer
