@@ -17,7 +17,11 @@
 #
 # ------------------------------------------------------------------------------
 
-"""This module contains the support resources for the yoti protocol."""
+"""
+This module contains the support resources for the yoti protocol.
+
+It was created with protocol buffer compiler version `libprotoc 3.11.4` and aea version `1.0.0`.
+"""
 
 from packages.fetchai.protocols.yoti.message import YotiMessage
 from packages.fetchai.protocols.yoti.serialization import YotiSerializer
