@@ -104,6 +104,8 @@ class DefaultDialogues(Model, BaseDefaultDialogues):
 class RegisterDialogue(BaseRegisterDialogue):
     """The dialogue class maintains state of a dialogue and manages it."""
 
+    __slots__ = ("_terms",)
+
     def __init__(
         self,
         dialogue_label: BaseDialogueLabel,
@@ -170,12 +172,15 @@ class RegisterDialogues(Model, BaseRegisterDialogues):
             self,
             self_address=self.context.agent_address,
             role_from_first_message=role_from_first_message,
+            dialogue_class=RegisterDialogue,
         )
 
 
 class ContractApiDialogue(BaseContractApiDialogue):
     """The dialogue class maintains state of a dialogue and manages it."""
 
+    __slots__ = ("_terms", "_associated_register_dialogue")
+
     def __init__(
         self,
         dialogue_label: BaseDialogueLabel,
@@ -258,7 +263,7 @@ class ContractApiDialogues(Model, BaseContractApiDialogues):
 
         BaseContractApiDialogues.__init__(
             self,
-            self_address=self.context.agent_address,
+            self_address=str(self.skill_id),
             role_from_first_message=role_from_first_message,
             dialogue_class=ContractApiDialogue,
         )
@@ -267,6 +272,8 @@ class ContractApiDialogues(Model, BaseContractApiDialogues):
 class LedgerApiDialogue(BaseLedgerApiDialogue):
     """The dialogue class maintains state of a dialogue and manages it."""
 
+    __slots__ = ("_associated_register_dialogue", "_terms")
+
     def __init__(
         self,
         dialogue_label: BaseDialogueLabel,
@@ -333,7 +340,7 @@ class LedgerApiDialogues(Model, BaseLedgerApiDialogues):
 
         BaseLedgerApiDialogues.__init__(
             self,
-            self_address=self.context.agent_address,
+            self_address=str(self.skill_id),
             role_from_first_message=role_from_first_message,
             dialogue_class=LedgerApiDialogue,
         )
@@ -342,6 +349,8 @@ class LedgerApiDialogues(Model, BaseLedgerApiDialogues):
 class SigningDialogue(BaseSigningDialogue):
     """The dialogue class maintains state of a dialogue and manages it."""
 
+    __slots__ = ("_associated_ledger_api_dialogue",)
+
     def __init__(
         self,
         dialogue_label: BaseDialogueLabel,
@@ -413,4 +422,5 @@ class SigningDialogues(Model, BaseSigningDialogues):
             self,
             self_address=str(self.skill_id),
             role_from_first_message=role_from_first_message,
+            dialogue_class=SigningDialogue,
         )
