@@ -70,7 +70,7 @@ class DefaultHandler(Handler):
         default_dialogues = cast(DefaultDialogues, self.context.default_dialogues)
         default_dialogue = cast(DefaultDialogue, default_dialogues.update(default_msg))
         if default_dialogue is None:
-            self._handle_unidentified_dialogue(default_dialogue)
+            self._handle_unidentified_dialogue(default_msg)
             return
 
         # handle message
@@ -83,7 +83,7 @@ class DefaultHandler(Handler):
         """
         Handle an unidentified dialogue.
 
-        :param fipa_msg: the message
+        :param default_msg: the message
         """
         self.context.logger.info(
             f"received invalid default message={default_msg}, unidentified dialogue."
