@@ -17,16 +17,22 @@
 #
 # ------------------------------------------------------------------------------
 
-"""This package contians the handlers for the Fetch oracle client skill."""
+"""This package contains the handlers for the Fetch oracle client skill."""
 
 from typing import Optional, cast
 
+from aea_ledger_fetchai import FetchAIApi
+
+from aea.common import JSONLike
 from aea.configurations.base import PublicId
 from aea.crypto.ledger_apis import LedgerApis
 from aea.protocols.base import Message
 from aea.skills.base import Handler
 
 from packages.fetchai.connections.ledger.base import CONNECTION_ID as LEDGER_API_ADDRESS
+from packages.fetchai.contracts.oracle_client.contract import (
+    PUBLIC_ID as CONTRACT_PUBLIC_ID,
+)
 from packages.fetchai.protocols.contract_api.message import ContractApiMessage
 from packages.fetchai.protocols.ledger_api.message import LedgerApiMessage
 from packages.fetchai.protocols.signing.message import SigningMessage
@@ -48,7 +54,6 @@ class LedgerApiHandler(Handler):
 
     def setup(self) -> None:
         """Implement the setup for the handler."""
-        pass
 
     def handle(self, message: Message) -> None:
         """
@@ -97,7 +102,6 @@ class LedgerApiHandler(Handler):
 
         :return: None
         """
-        pass
 
     def _handle_unidentified_dialogue(self, ledger_api_msg: LedgerApiMessage) -> None:
         """
@@ -145,6 +149,46 @@ class LedgerApiHandler(Handler):
         self.context.outbox.put_message(message=msg)
         self.context.logger.info("requesting transaction receipt.")
 
+    def _request_init_transaction(self, ledger_id: str, tx_receipt: JSONLike) -> None:
+        """
+        Send a message to request the initialisation transaction to finalise contract deployment
+
+        :param ledger_api_message: the ledger api message
+        """
+        strategy = cast(Strategy, self.context.strategy)
+        contract_api_dialogues = cast(
+            ContractApiDialogues, self.context.contract_api_dialogues
+        )
+        fetchai_api = cast(FetchAIApi, LedgerApis.get_api(ledger_id))
+        code_id = fetchai_api.get_code_id(tx_receipt)  # type: Optional[int]
+        if code_id:
+            contract_api_msg, dialogue = contract_api_dialogues.create(
+                counterparty=str(LEDGER_API_ADDRESS),
+                performative=ContractApiMessage.Performative.GET_DEPLOY_TRANSACTION,
+                ledger_id=ledger_id,
+                contract_id=str(CONTRACT_PUBLIC_ID),
+                callable="get_deploy_transaction",
+                kwargs=ContractApiMessage.Kwargs(
+                    {
+                        "label": "OracleContract",
+                        "init_msg": {
+                            "oracle_contract_address": strategy.oracle_contract_address
+                        },
+                        "gas": strategy.default_gas_deploy,
+                        "amount": 0,
+                        "code_id": code_id,
+                        "deployer_address": self.context.agent_address,
+                    }
+                ),
+            )
+            contract_api_dialogue = cast(ContractApiDialogue, dialogue)
+            contract_api_dialogue.terms = strategy.get_deploy_terms(
+                is_init_transaction=True
+            )
+            self.context.outbox.put_message(message=contract_api_msg)
+        else:  # pragma: nocover
+            self.context.logger.info("Failed to initialize contract: code_id not found")
+
     def _handle_transaction_receipt(
         self, ledger_api_msg: LedgerApiMessage, ledger_api_dialogue: LedgerApiDialogue
     ) -> None:
@@ -153,6 +197,9 @@ class LedgerApiHandler(Handler):
 
         :param ledger_api_message: the ledger api message
         """
+        ledger_id = cast(str, ledger_api_msg.transaction_receipt.ledger_id)
+        tx_receipt = cast(JSONLike, ledger_api_msg.transaction_receipt.receipt)
+
         is_transaction_successful = LedgerApis.is_transaction_settled(
             ledger_api_msg.transaction_receipt.ledger_id,
             ledger_api_msg.transaction_receipt.receipt,
@@ -171,22 +218,26 @@ class LedgerApiHandler(Handler):
 
             transaction_label = contract_api_dialogue.terms.kwargs.get("label", "None")
 
-            if (
-                not strategy.is_client_contract_deployed
-                and transaction_label == "deploy"
-            ):
-                client_contract_address = cast(
-                    str,
-                    ledger_api_msg.transaction_receipt.receipt.get(
-                        "contractAddress", None
-                    ),
-                )
-                strategy.client_contract_address = client_contract_address
-                strategy.is_client_contract_deployed = is_transaction_successful
-                strategy.is_behaviour_active = is_transaction_successful
-                self.context.logger.info(
-                    "Oracle client contract successfully deployed!"
-                )
+            if not strategy.is_client_contract_deployed:
+                if transaction_label == "store":
+                    self._request_init_transaction(ledger_id, tx_receipt)
+                elif transaction_label in {"deploy", "init"}:
+                    client_contract_address = LedgerApis.get_contract_address(
+                        ledger_id, tx_receipt
+                    )
+                    if client_contract_address is None:
+                        raise ValueError(
+                            "No contract address found."
+                        )  # pragma: nocover
+                    strategy.client_contract_address = client_contract_address
+                    strategy.is_client_contract_deployed = True
+                    self.context.logger.info(
+                        f"Oracle client contract successfully deployed at address: {client_contract_address}"
+                    )
+                else:
+                    self.context.logger.error(
+                        f"Invalid transaction label: {transaction_label}"
+                    )  # pragma: nocover
             elif (
                 not strategy.is_oracle_transaction_approved
                 and transaction_label == "approve"
@@ -247,7 +298,6 @@ class ContractApiHandler(Handler):
 
     def setup(self) -> None:
         """Implement the setup for the handler."""
-        pass
 
     def handle(self, message: Message) -> None:
         """
@@ -290,7 +340,6 @@ class ContractApiHandler(Handler):
 
         :return: None
         """
-        pass
 
     def _handle_unidentified_dialogue(
         self, contract_api_msg: ContractApiMessage
@@ -374,7 +423,6 @@ class SigningHandler(Handler):
 
     def setup(self) -> None:
         """Implement the setup for the handler."""
-        pass
 
     def handle(self, message: Message) -> None:
         """
@@ -408,7 +456,6 @@ class SigningHandler(Handler):
 
         :return: None
         """
-        pass
 
     def _handle_unidentified_dialogue(self, signing_msg: SigningMessage) -> None:
         """
