@@ -68,7 +68,6 @@ def update_version_for_files(current_version: str, new_version: str) -> None:
     """
     files = [
         Path("benchmark", "run_from_branch.sh"),
-        Path("deploy-image", "docker-env.sh"),
         Path("deploy-image", "Dockerfile"),
         Path("develop-image", "docker-env.sh"),
         Path("docs", "quickstart.md"),
@@ -94,7 +93,7 @@ def update_version_for_aea(new_version: str) -> str:
         for line in fin:
             if "__version__" not in line:
                 continue
-            match = re.search(VERSION_REGEX, line)
+            match = re.search('__version__ = "(.*)"', line)
             if match is None:
                 raise ValueError("Current version is not well formatted.")
             current_version = match.group(1)
@@ -169,11 +168,16 @@ if __name__ == "__main__":
     arguments = parse_args()
     _new_version_str = arguments.new_version
 
+    # validate new version
+    _new_version: Version = Version(_new_version_str)
+    _new_version_str = str(_new_version)
     _current_version_str = update_version_for_aea(_new_version_str)
+
+    # validate current version
+    _current_version: Version = Version(_current_version_str)
+    _current_version_str = str(_current_version)
     update_version_for_files(_current_version_str, _new_version_str)
 
-    _new_version: Version = Version(_new_version_str)
-    _current_version: Version = Version(_current_version_str)
     have_updated_specifier_set = update_aea_version_specifiers(
         _current_version, _new_version
     )
