@@ -22,6 +22,7 @@
 # To update; run: vulture aea --exclude "*_pb2.py" --make-whitelist > tests/whitelist.py
 _.dependencies_highest_version  # unused property (aea/aea_builder.py:116)
 _.set_search_service_address  # unused method (aea/aea_builder.py:484)
+_.set_required_ledgers  # unused method (aea/aea_builder.py:850)
 _.remove_private_key  # unused method (aea/aea_builder.py:580)
 _.add_component_instance  # unused method (aea/aea_builder.py:643)
 _.set_context_namespace  # unused method (aea/aea_builder.py:663)
@@ -195,6 +196,7 @@ MultiAgentManager  # unused class (aea/manager.py:127)
 _.add_error_callback  # unused method (aea/manager.py:202)
 _.start_manager  # unused method (aea/manager.py:208)
 _.stop_manager  # unused method (aea/manager.py:221)
+_.projects  # unused property (aea/manager.py:228)
 _.add_project  # unused method (aea/manager.py:263)
 _.list_projects  # unused method (aea/manager.py:283)
 _.list_agents_info  # unused method (aea/manager.py:283)
@@ -252,3 +254,8 @@ _.__path__  # unused attribute (aea/components/base.py:140)
 _.__path__  # unused attribute (aea/components/base.py:143)
 short_help  # unused method (aea/cli/plugin.py:83)
 parse_args  # unused method (aea/cli/plugin.py:99)
+encrypt  # unused method (aea/crypto/base.py:148)
+decrypt  # unused method (aea/crypto/base.py:158)
+keyfile_json  # unused variable (aea/crypto/base.py:159)
+DecryptError  # unused class (aea/crypto/helpers.py:195)
+hex_to_bytes_for_key  # unused function (aea/crypto/helpers.py:209)
