@@ -17,6 +17,7 @@
 #
 # ------------------------------------------------------------------------------
 """Conftest module for Pytest."""
+import contextlib
 import difflib
 import inspect
 import logging
@@ -26,6 +27,7 @@ import random
 import shutil
 import socket
 import string
+import subprocess  # nosec
 import sys
 import tempfile
 import threading
@@ -52,7 +54,7 @@ import gym
 import pytest
 from aea_ledger_cosmos import CosmosCrypto
 from aea_ledger_ethereum import EthereumCrypto
-from aea_ledger_fetchai import FetchAICrypto
+from aea_ledger_fetchai import DEFAULT_CLI_COMMAND, FetchAICrypto
 
 from aea import AEA_DIR
 from aea.aea import AEA
@@ -104,6 +106,7 @@ from packages.fetchai.connections.tcp.tcp_server import TCPServerConnection
 
 from tests.common.docker_image import (
     DockerImage,
+    FetchLedgerDockerImage,
     GanacheDockerImage,
     OEFSearchDockerImage,
 )
@@ -146,6 +149,19 @@ DEFAULT_GANACHE_ADDR = "http://127.0.0.1"
 DEFAULT_GANACHE_PORT = 8545
 DEFAULT_GANACHE_CHAIN_ID = 1337
 
+# URL to local Fetch ledger instance
+DEFAULT_FETCH_DOCKER_IMAGE_TAG = "fetchai/fetchd:0.2.7"
+DEFAULT_FETCH_LEDGER_ADDR = "http://127.0.0.1"
+DEFAULT_FETCH_LEDGER_RPC_PORT = 26657
+DEFAULT_FETCH_LEDGER_REST_PORT = 1317
+DEFAULT_FETCH_ADDR_REMOTE = "https://rpc-agent-land.fetch.ai:443"
+DEFAULT_FETCH_MNEMONIC = "gap bomb bulk border original scare assault pelican resemble found laptop skin gesture height inflict clinic reject giggle hurdle bubble soldier hurt moon hint"
+DEFAULT_MONIKER = "test-node"
+DEFAULT_FETCH_CHAIN_ID = "agent-land"
+DEFAULT_GENESIS_ACCOUNT = "validator"
+DEFAULT_DENOMINATION = "atestfet"
+FETCHD_INITIAL_TX_SLEEP = 6
+
 COSMOS_PRIVATE_KEY_FILE_CONNECTION = "cosmos_connection_private_key.txt"
 FETCHAI_PRIVATE_KEY_FILE_CONNECTION = "fetchai_connection_private_key.txt"
 
@@ -187,6 +203,12 @@ NON_FUNDED_COSMOS_PRIVATE_KEY_1 = (
 NON_FUNDED_FETCHAI_PRIVATE_KEY_1 = (
     "b6ef49c3078f300efe2d4480e179362bd39f20cbb2087e970c8f345473661aa5"
 )
+FUNDED_FETCHAI_PRIVATE_KEY_1 = (
+    "f848e125edb124d7752338fdd15825cd031b8c7f38627ec50ccccb7d75ecffdb"
+)
+FUNDED_FETCHAI_PRIVATE_KEY_2 = (
+    "9d6459d1f93dd153335291af940f6b5224a34a9a1e1062e2158a45fa4901ed3f"
+)
 
 # addresses with no value on testnet
 COSMOS_ADDRESS_ONE = "cosmos1z4ftvuae5pe09jy2r7udmk6ftnmx504alwd5qf"
@@ -195,6 +217,8 @@ ETHEREUM_ADDRESS_ONE = "0x46F415F7BF30f4227F98def9d2B22ff62738fD68"
 ETHEREUM_ADDRESS_TWO = "0x7A1236d5195e31f1F573AD618b2b6FEFC85C5Ce6"
 FETCHAI_ADDRESS_ONE = "fetch1paqxtqnfh7da7z9c05l3y3lahe8rhd0nm0jk98"
 FETCHAI_ADDRESS_TWO = "fetch19j4dc3e6fgle98pj06l5ehhj6zdejcddx7teac"
+FUNDED_FETCHAI_ADDRESS_ONE = "fetch1dm72s3yravky6t7rp3daajwwsz2vrqd86g2v47"
+FUNDED_FETCHAI_ADDRESS_TWO = "fetch1x2vfp8ec2yk8nnlzn52agflpmpwtucm6yj2hw4"
 
 # P2P addresses
 COSMOS_P2P_ADDRESS = "/dns4/127.0.0.1/tcp/9000/p2p/16Uiu2HAmAzvu5uNbcnD2qaqrkSULhJsc6GJUg3iikWerJkoD72pr"  # relates to NON_FUNDED_COSMOS_PRIVATE_KEY_1
@@ -238,7 +262,7 @@ FETCHAI_TESTNET_CONFIG = {"address": FETCHAI_DEFAULT_ADDRESS}
 # common public ids used in the tests
 UNKNOWN_PROTOCOL_PUBLIC_ID = PublicId("unknown_author", "unknown_protocol", "0.1.0")
 UNKNOWN_CONNECTION_PUBLIC_ID = PublicId("unknown_author", "unknown_connection", "0.1.0")
-MY_FIRST_AEA_PUBLIC_ID = PublicId.from_str("fetchai/my_first_aea:0.23.0")
+MY_FIRST_AEA_PUBLIC_ID = PublicId.from_str("fetchai/my_first_aea:0.26.0")
 
 DUMMY_SKILL_PATH = os.path.join(CUR_PATH, "data", "dummy_skill", SKILL_YAML)
 
@@ -523,7 +547,7 @@ def ganache_addr() -> str:
 
 @pytest.fixture(scope="session")
 def ganache_port() -> int:
-    """Port of the connection to the OEF Node to use during the tests."""
+    """Port of the connection to the Ganache Node to use during the tests."""
     return DEFAULT_GANACHE_PORT
 
 
@@ -644,6 +668,18 @@ def ganache_configuration():
     )
 
 
+@pytest.fixture(scope="session")
+def fetchd_configuration():
+    """Get the Fetch ledger configuration for testing purposes."""
+    return dict(
+        mnemonic=DEFAULT_FETCH_MNEMONIC,
+        moniker=DEFAULT_MONIKER,
+        chain_id=DEFAULT_FETCH_CHAIN_ID,
+        genesis_account=DEFAULT_GENESIS_ACCOUNT,
+        denom=DEFAULT_DENOMINATION,
+    )
+
+
 @pytest.fixture(scope="session")
 def ethereum_testnet_config(ganache_addr, ganache_port):
     """Get Ethereum ledger api configurations using Ganache."""
@@ -686,11 +722,30 @@ def ganache(
     yield from _launch_image(image, timeout=timeout, max_attempts=max_attempts)
 
 
+@pytest.mark.integration
+@pytest.mark.ledger
+@pytest.fixture(scope="session")
+@action_for_platform("Linux", skip=False)
+def fetchd(
+    fetchd_configuration, timeout: float = 2.0, max_attempts: int = 4,
+):
+    """Launch the Fetch ledger image."""
+    client = docker.from_env()
+    image = FetchLedgerDockerImage(
+        client,
+        DEFAULT_FETCH_LEDGER_ADDR,
+        DEFAULT_FETCH_LEDGER_RPC_PORT,
+        DEFAULT_FETCH_DOCKER_IMAGE_TAG,
+        config=fetchd_configuration,
+    )
+    yield from _launch_image(image, timeout=timeout, max_attempts=max_attempts)
+
+
 def _launch_image(image: DockerImage, timeout: float = 2.0, max_attempts: int = 10):
     """
     Launch image.
 
-    :param image: an instancoe of Docker image.
+    :param image: an instance of Docker image.
     :return: None
     """
     image.check_skip()
@@ -862,15 +917,14 @@ def _make_libp2p_connection(
     key = agent_key
     if key is None:
         key = make_crypto(DEFAULT_LEDGER)
-    identity = Identity("", address=key.address)
+    identity = Identity("identity", address=key.address)
     conn_crypto_store = None
     if node_key_file is not None:
         conn_crypto_store = CryptoStore({DEFAULT_LEDGER: node_key_file})
     else:
         node_key = make_crypto(DEFAULT_LEDGER)
         node_key_path = os.path.join(data_dir, f"{node_key.public_key}.txt")
-        with open(node_key_path, "wb") as f:
-            node_key.dump(f)
+        node_key.dump(node_key_path)
         conn_crypto_store = CryptoStore({DEFAULT_LEDGER: node_key_path})
     cert_request = CertRequest(
         conn_crypto_store.public_keys[DEFAULT_LEDGER],
@@ -878,6 +932,7 @@ def _make_libp2p_connection(
         key.identifier,
         "2021-01-01",
         "2021-01-02",
+        "{public_key}",
         f"./{key.address}_cert.txt",
     )
     _process_cert(key, cert_request, path_prefix=data_dir)
@@ -941,18 +996,19 @@ def _make_libp2p_client_connection(
     if not os.path.isdir(data_dir) or not os.path.exists(data_dir):
         raise ValueError("Data dir must be directory and exist!")
     crypto = make_crypto(ledger_api_id)
-    identity = Identity("", address=crypto.address)
+    identity = Identity("identity", address=crypto.address)
     cert_request = CertRequest(
         peer_public_key,
         POR_DEFAULT_SERVICE_ID,
         ledger_api_id,
         "2021-01-01",
         "2021-01-02",
+        "{public_key}",
         f"./{crypto.address}_cert.txt",
     )
     _process_cert(crypto, cert_request, path_prefix=data_dir)
     configuration = ConnectionConfig(
-        client_key_file=None,
+        tcp_key_file=None,
         nodes=[
             {
                 "uri": str(uri)
@@ -1001,11 +1057,9 @@ def libp2p_log_on_failure_all(cls):
 
     :return: class with decorated methods.
     """
-    # TODO(LR) test it is a type
     for name, fn in inspect.getmembers(cls):
         if isinstance(fn, FunctionType):
             setattr(cls, name, libp2p_log_on_failure(fn))
-        # TOFIX(LR) decorate already @classmethod decorated methods
         continue
         if isinstance(fn, MethodType):
             if fn.im_self is None:
@@ -1265,6 +1319,55 @@ def oracle_contract(ledger_api, ganache, ganache_addr, ganache_port, erc20_contr
     yield contract, contract_address
 
 
+def docker_exec_cmd(image_tag: str, cmd: str, **kwargs):
+    """Execute a command in running docker containers matching image tag."""
+    client = docker.from_env()
+    for container in client.containers.list():
+        if image_tag in container.image.tags:
+            logger.info(f"Running command '{cmd}' in docker container {image_tag}")
+            resp = container.exec_run(cmd, **kwargs)
+            logger.info(resp)
+
+
+def fund_accounts_from_local_validator(
+    addresses: str, amount: int, denom: str = DEFAULT_DENOMINATION
+):
+    """Send funds to local accounts from the local genesis validator."""
+    for address in addresses:
+        time.sleep(FETCHD_INITIAL_TX_SLEEP)
+        cmd = f'sh -c "echo y | {DEFAULT_CLI_COMMAND} tx send {DEFAULT_GENESIS_ACCOUNT} {address} {amount}{denom} --chain-id {DEFAULT_FETCH_CHAIN_ID}"'
+        docker_exec_cmd(DEFAULT_FETCH_DOCKER_IMAGE_TAG, cmd)
+
+
+@pytest.fixture()
+def fund_fetchai_accounts(fetchd):
+    """Fund test accounts from local validator."""
+    fund_accounts_from_local_validator(
+        [FUNDED_FETCHAI_ADDRESS_ONE, FUNDED_FETCHAI_ADDRESS_TWO], 10000000000000000000,
+    )
+
+
+@contextlib.contextmanager
+def use_local_fetchcli_config():
+    """Context manager for temporarily configuring the Fetch CLI for the locally running test node"""
+    cmd = [
+        DEFAULT_CLI_COMMAND,
+        "config",
+        "node",
+        f"{DEFAULT_FETCH_LEDGER_ADDR}:{DEFAULT_FETCH_LEDGER_RPC_PORT}",
+    ]
+    logger.info(
+        f"Directing the Fetch ledger CLI to the locally running test node: {cmd}"
+    )
+    subprocess.run(cmd, stdout=subprocess.PIPE, check=True)  # nosec
+    yield
+    cmd = [DEFAULT_CLI_COMMAND, "config", "node", DEFAULT_FETCH_ADDR_REMOTE]
+    logger.info(
+        f"Directing the Fetch ledger CLI back to the default remote endpoint {cmd}"
+    )
+    subprocess.run(cmd, stdout=subprocess.PIPE, check=True)  # nosec
+
+
 def env_path_separator() -> str:
     """
     Get the separator between path items in PATH variables, cross platform.
@@ -1303,6 +1406,15 @@ class UseGanache:
         """Start a Ganache image."""
 
 
+@pytest.mark.integration
+class UseLocalFetchNode:
+    """Inherit from this class to use a local Fetch ledger node."""
+
+    @pytest.fixture(autouse=True)
+    def _start_fetchd(self, fetchd):
+        """Start a Fetch ledger image."""
+
+
 @pytest.fixture()
 def change_directory():
     """Change directory and execute the test."""
