@@ -17,7 +17,11 @@
 #
 # ------------------------------------------------------------------------------
 
-"""This module contains the support resources for the t_protocol_no_ct protocol."""
+"""
+This module contains the support resources for the t_protocol_no_ct protocol.
+
+It was created with protocol buffer compiler version `libprotoc 3.11.4` and aea version `1.0.0`.
+"""
 
 from tests.data.generator.t_protocol_no_ct.message import TProtocolNoCtMessage
 from tests.data.generator.t_protocol_no_ct.serialization import TProtocolNoCtSerializer
