@@ -44,7 +44,7 @@ class GetAddressTestCase(TestCase):
 
 
 @mock.patch("aea.cli.utils.decorators.try_to_load_agent_config")
-@mock.patch("aea.cli.utils.package_utils.verify_or_create_private_keys_ctx")
+@mock.patch("aea.cli.utils.package_utils.verify_private_keys_ctx")
 @mock.patch("aea.cli.get_address._try_get_address")
 @mock.patch("aea.cli.get_address.click.echo")
 class GetAddressCommandTestCase(TestCase):
