@@ -68,8 +68,10 @@ class TestEchoSkill(AEATestCaseEmpty):
 
     def test_echo(self):
         """Run the echo skill sequence."""
-        self.add_item("connection", "fetchai/stub:0.18.0")
-        self.add_item("skill", "fetchai/echo:0.15.0")
+        self.generate_private_key()
+        self.add_private_key()
+        self.add_item("connection", "fetchai/stub:0.20.0")
+        self.add_item("skill", "fetchai/echo:0.18.0")
 
         process = self.run_agent()
         is_running = self.is_running(process)
