@@ -57,9 +57,9 @@ class TestERCSkillsEthereumLedger(AEATestCaseManyFlaky, UseGanache):
 
         # add ethereum ledger in both configuration files
         default_routing = {
-            "fetchai/ledger_api:0.11.0": "fetchai/ledger:0.15.0",
-            "fetchai/contract_api:0.12.0": "fetchai/ledger:0.15.0",
-            "fetchai/oef_search:0.14.0": "fetchai/soef:0.19.0",
+            "fetchai/ledger_api:1.0.0": "fetchai/ledger:0.18.0",
+            "fetchai/contract_api:1.0.0": "fetchai/ledger:0.18.0",
+            "fetchai/oef_search:1.0.0": "fetchai/soef:0.22.0",
         }
 
         # generate random location
@@ -70,14 +70,18 @@ class TestERCSkillsEthereumLedger(AEATestCaseManyFlaky, UseGanache):
 
         # add packages for agent one
         self.set_agent_context(deploy_aea_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.18.0")
-        self.add_item("connection", "fetchai/ledger:0.15.0")
-        self.add_item("connection", "fetchai/soef:0.19.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.18.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.21.0")
+        self.add_item("connection", "fetchai/ledger:0.18.0")
+        self.add_item("connection", "fetchai/soef:0.22.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.21.0")
         self.set_config("agent.default_ledger", EthereumCrypto.identifier)
+        self.nested_set_config(
+            "agent.required_ledgers",
+            [FetchAICrypto.identifier, EthereumCrypto.identifier],
+        )
         setting_path = "agent.default_routing"
         self.nested_set_config(setting_path, default_routing)
-        self.add_item("skill", "fetchai/erc1155_deploy:0.24.0")
+        self.add_item("skill", "fetchai/erc1155_deploy:0.27.0")
 
         self.generate_private_key(EthereumCrypto.identifier)
         self.add_private_key(EthereumCrypto.identifier, ETHEREUM_PRIVATE_KEY_FILE)
@@ -106,6 +110,7 @@ class TestERCSkillsEthereumLedger(AEATestCaseManyFlaky, UseGanache):
                     "not_after": "2022-01-01",
                     "not_before": "2021-01-01",
                     "public_key": FetchAICrypto.identifier,
+                    "message_format": "{public_key}",
                     "save_path": ".certs/conn_cert.txt",
                 }
             ]
@@ -120,7 +125,7 @@ class TestERCSkillsEthereumLedger(AEATestCaseManyFlaky, UseGanache):
         self.nested_set_config(setting_path, location)
 
         diff = self.difference_to_fetched_agent(
-            "fetchai/erc1155_deployer:0.26.0", deploy_aea_name
+            "fetchai/erc1155_deployer:0.29.0", deploy_aea_name
         )
         assert (
             diff == []
@@ -128,14 +133,18 @@ class TestERCSkillsEthereumLedger(AEATestCaseManyFlaky, UseGanache):
 
         # add packages for agent two
         self.set_agent_context(client_aea_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.18.0")
-        self.add_item("connection", "fetchai/ledger:0.15.0")
-        self.add_item("connection", "fetchai/soef:0.19.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.18.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.21.0")
+        self.add_item("connection", "fetchai/ledger:0.18.0")
+        self.add_item("connection", "fetchai/soef:0.22.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.21.0")
         self.set_config("agent.default_ledger", EthereumCrypto.identifier)
+        self.nested_set_config(
+            "agent.required_ledgers",
+            [FetchAICrypto.identifier, EthereumCrypto.identifier],
+        )
         setting_path = "agent.default_routing"
         self.nested_set_config(setting_path, default_routing)
-        self.add_item("skill", "fetchai/erc1155_client:0.23.0")
+        self.add_item("skill", "fetchai/erc1155_client:0.26.0")
 
         self.generate_private_key(EthereumCrypto.identifier)
         self.add_private_key(EthereumCrypto.identifier, ETHEREUM_PRIVATE_KEY_FILE)
@@ -163,6 +172,7 @@ class TestERCSkillsEthereumLedger(AEATestCaseManyFlaky, UseGanache):
                     "not_after": "2022-01-01",
                     "not_before": "2021-01-01",
                     "public_key": FetchAICrypto.identifier,
+                    "message_format": "{public_key}",
                     "save_path": ".certs/conn_cert.txt",
                 }
             ]
@@ -177,7 +187,7 @@ class TestERCSkillsEthereumLedger(AEATestCaseManyFlaky, UseGanache):
         self.nested_set_config(setting_path, location)
 
         diff = self.difference_to_fetched_agent(
-            "fetchai/erc1155_client:0.26.0", client_aea_name
+            "fetchai/erc1155_client:0.29.0", client_aea_name
         )
         assert (
             diff == []
