@@ -37,12 +37,14 @@ class TestHttpEchoSkill(AEATestCaseEmpty):
 
     def test_echo(self):
         """Run the echo skill sequence."""
-        self.add_item("connection", "fetchai/http_server:0.18.0")
-        self.add_item("skill", "fetchai/http_echo:0.16.0")
-        self.set_config("agent.default_connection", "fetchai/http_server:0.18.0")
+        self.generate_private_key()
+        self.add_private_key()
+        self.add_item("connection", "fetchai/http_server:0.21.0")
+        self.add_item("skill", "fetchai/http_echo:0.19.0")
+        self.set_config("agent.default_connection", "fetchai/http_server:0.21.0")
         self.set_config(
             "vendor.fetchai.connections.http_server.config.target_skill_id",
-            "fetchai/http_echo:0.16.0",
+            "fetchai/http_echo:0.19.0",
         )
         self.set_config(
             "vendor.fetchai.connections.http_server.config.api_spec_path", API_SPEC_PATH
